@@ -1,27 +1,41 @@
-#' @title Hierarchical clustering with geographical contraints
-#' @description This function implements a Ward-like hierarchical clustering algorithm 
-#' including soft contiguity constraints. This algorithm takes as input two dissimilarity matrices 
-#' D0 and D1 and a mixing parameter alpha between 0 an 1. The dissimilarities can be non 
-#' euclidean and the weights of the observations can be non uniform. 
-#' The first matrix gives the dissimilarities in the "feature space" 
-#' (socio-demographic variables or grey levels for instance). The second matrix gives the dissimilarities in the 
-#'  "constraint" space. For instance, D1 can be a matrix of geographical distances or a matrix 
-#' build from the contiguity matrix C.
-#' The mixing parameter alpha sets the importance of the constraint in the clustering procedure. 
-#' @param D0 an object of class "dist" with the dissimilarities between the n observations. 
-#' The function \code{\link{as.dist}} can be used to transform an object of class matrix to object of class "dist".
-#' @param D1 an object of class "dist" with other dissimilarities between the same n observations. 
-#' @param alpha  a real value between 0 and 1. This mixing parameter gives the relative importance of D0 compared to D1.
-#' By default, this parameter is equal to 0 and D0 is used alone in the clustering process.  
+#' @title Ward clustering with soft contiguity contraints
+#' 
+#' @description Implements a Ward-like hierarchical clustering 
+#' algorithm including soft contiguity constraints. The algorithm takes as
+#' input two dissimilarity matrices \code{D0} and \code{D1} and a mixing 
+#' parameter alpha between 0 an 1. The dissimilarities can be non euclidean 
+#' and the weights of the observations can be non uniform. The first matrix 
+#' gives the dissimilarities in the "feature space". The second matrix gives 
+#' the dissimilarities in the  "constraint" space. For instance, \code{D1}
+#'  can be a matrix of geographical distances or a matrix  build from 
+#'  a contiguity matrix. The mixing parameter \code{alpha} sets the importance 
+#'  of the constraint in the clustering process. 
+#' 
+#' @param D0 an object of class \code{dist} with the dissimilarities between the n observations. 
+#' The function \code{\link{as.dist}} can be used to transform an object of 
+#' class \code{matrix} to object of class \code{dist}.
+#' @param D1 an object of class "dist" with other dissimilarities between the 
+#' same n observations. 
+#' @param alpha  a real value between 0 and 1. This mixing parameter gives the 
+#' relative importance of \code{D0} compared to \code{D1}.
+#' By default, this parameter is equal to 0 and \code{D0} is used alone in the
+#'  clustering process.  
 #' @param wt vector with the weights of the observations. By default, wt=NULL corresponds to
 #' the case where all observations are weighted by 1/n.
-#' @param scale if TRUE the two dissimilarity matrix D0 and D1 are scaled i.e. divided by their max. If D1=NULL, 
-#' this parameter is no used and D0 is not scaled.
+#' @param scale if TRUE the two dissimilarity matric \code{D0} and \code{D1} 
+#' are scaled i.e. divided by their max. If \code{D1}=NULL, this parameter 
+#' is no used and D0 is not scaled.
+#' 
 #' @return Returns an object of class \code{\link{hclust}}.
-#' @details The criterion minimized at each stage is a convex combination of the homogeneity criterion 
-#'  calculated with D0 and the homogeneity criterion calculated with D1. 
-#'  The parameter alpha (the weight of this convex combination) controls the weight of the constraint in the quality of the solutions. 
-#'  When alpha increases, the homogeneity calculated with D0 decreases whereas the homogeneity calculated with D1 increases. 
+#' 
+#' @details The criterion minimized at each stage is a convex combination of
+#'  the homogeneity criterion calculated with \code{D0} and the homogeneity 
+#'  criterion calculated with \code{D1}. The parameter \code{alpha} (the weight
+#'  of this convex combination) controls the importance of the constraint 
+#'  in the quality of the solutions. When \code{alpha} increases, 
+#'  the homogeneity calculated with \code{D0} decreases whereas the
+#'  homogeneity calculated with \code{D1} increases. 
+#' 
 #' @examples
 #' data(estuary)
 #' # with one dissimilarity matrix
@@ -33,7 +47,7 @@
 #' inert(estuary$dat,w=w)
 #' plot(tree,labels=FALSE)
 #' part <- cutree(tree,k=5)
-#' sp::plot(estuary$map,border="grey",col=part)
+#' sp::plot(estuary$map, border = "grey", col = part)
 #' 
 #' # with two dissimilarity matrix
 #' D0 <- dist(estuary$dat) # the socio-demographic distances
@@ -42,10 +56,15 @@
 #' tree <- hclustgeo(D0,D1,alpha=alpha,wt=w)
 #' plot(tree,labels=FALSE)
 #' part <- cutree(tree,k=5)
-#' sp::plot(estuary$map,border="grey",col=part)
+#' sp::plot(estuary$map, border = "grey", col = part)
+#' 
+#' @seealso \code{\link{choicealpha}}
+#' 
 #' @references 
-#' M.chavent, V. Kuentz-Simonet, A. Labenne, J. Saracco.  ClustGeo:  an R package 
-#' for hierarchical clustering with spatial constraints	arXiv:1707.03897 [stat.CO]
+#' M. Chavent, V. Kuentz-Simonet, A. Labenne, J. Saracco. ClustGeo: an R package
+#' for hierarchical clustering with spatial constraints.
+#' Comput Stat (2018) 33: 1799-1822. 
+#' 
 #' @export
 
 
@@ -78,7 +97,7 @@ hclustgeo <- function(D0, D1=NULL, alpha=0,scale=TRUE, wt=NULL) {
   delta <-(1-alpha)*delta0 + alpha*delta1
   
   #Hierarchical clustering
-  res <- hclust(delta,method="ward.D",members=wt)
+  res <- stats::hclust(delta,method="ward.D",members=wt)
   return(res)
 }
 
@@ -96,10 +115,10 @@ hclustgeo <- function(D0, D1=NULL, alpha=0,scale=TRUE, wt=NULL) {
 #' calculated on data coming from the French National Institute of Geographical and Forestry 
 #' Information. The calculation of the ratio and recoding of categories have been made by 
 #' Irstea Bordeaux.
-#' @description Data refering to n=303 french municipalities  of gironde estuary (a south-ouest french county).
+#' @description Data refering to n=303 French municipalities  of gironde estuary (a south-ouest French county).
 #' The data are issued from the French population census conducted by the National Institute 
 #' of Statistics and Economic Studies. The dataset is an extraction of four quantitative 
-#' socio-economic variables for a subsample of 303 french municipalities located on the
+#' socio-economic variables for a subsample of 303 French municipalities located on the
 #' atlantic coast between Royan and Mimizan. \code{employ.rate.city} is the employment rate 
 #' of the municipality, that is the ratio of the number of individuals who have a job to 
 #' the population of working age (generally defined, for the purposes of international 
@@ -112,27 +131,13 @@ hclustgeo <- function(D0, D1=NULL, alpha=0,scale=TRUE, wt=NULL) {
 #' agricultural area of the municipality.
 #' @keywords data
 #' @references 
-#' M.chavent, V. Kuentz-Simonet, A. Labenne, J. Saracco.  ClustGeo:  an R package 
-#' for hierarchical clustering with spatial constraints	arXiv:1707.03897 [stat.CO]
+#' M. Chavent, V. Kuentz-Simonet, A. Labenne, J. Saracco. ClustGeo: an R package
+#' for hierarchical clustering with spatial constraints.
+#' Comput Stat (2018) 33: 1799-1822. 
+#' 
 #' @examples
 #' data(estuary)
 #' names(estuary)
 #' head(estuary$dat)
-#' sp::plot(estuary$map)
-NULL
-
-#' @importFrom graphics legend matplot mtext
-NULL 
-#' @importFrom stats as.dist cutree hclust
-NULL
-#' @importMethodsFrom sp plot
-NULL
-#' @importMethodsFrom sp coordinates
-NULL
-#' @importClassesFrom sp SpatialPolygonsDataFrame
-NULL
-#' @importFrom spdep nb2mat
-NULL
-#' @importFrom spdep poly2nb
 NULL
 
